<?php

namespace Drupal\text_clarity_checker\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Configure Text Clarity Checker settings.
 */
class TextClarityCheckerSettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['text_clarity_checker.config'];
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'text_clarity_checker_settings';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('text_clarity_checker.config');

    $form['metrics_settings'] = [
      '#type' => 'details',
      '#title' => $this->t('Metrics Settings'),
      '#open' => TRUE,
    ];

    $form['metrics_settings']['text_metrics'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Enable text metrics analysis'),
      '#description' => $this->t('Check text length, reading time and paragraphs metrics.'),
      '#default_value' => $config->get('text_metrics'),
    ];

    $form['metrics_settings']['images'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Enable images analysis'),
      '#description' => $this->t('Check images count, decorative images and background images.'),
      '#default_value' => $config->get('images'),
    ];

    $form['metrics_settings']['recommended_image_metrics'] = [
      '#type' => 'number',
      '#title' => $this->t('Recommended number of images per content'),
      '#description' => $this->t('Set the optimal number of content images.'),
      '#min' => 0,
      '#max' => 20,
      '#step' => 1,
      '#default_value' => $config->get('recommended_image_metrics') ?? 1,
    ];

    $form['metrics_settings']['links'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Enable links analysis'),
      '#description' => $this->t('Check internal and external links count.'),
      '#default_value' => $config->get('links'),
    ];

    $form['metrics_settings']['recommended_link_metrics'] = [
      '#type' => 'number',
      '#title' => $this->t('Recommended number of links per content'),
      '#description' => $this->t('Set the optimal number of links internal or external.'),
      '#min' => 0,
      '#max' => 20,
      '#step' => 1,
      '#default_value' => $config->get('recommended_link_metrics') ?? 1,
    ];

    $form['metrics_settings']['recommended_external_link_metrics'] = [
      '#type' => 'number',
      '#title' => $this->t('Recommended number of links per content'),
      '#description' => $this->t('Set the optimal number of links internal or external.'),
      '#min' => 0,
      '#max' => 20,
      '#step' => 1,
      '#default_value' => $config->get('recommended_external_link_metrics') ?? 1,
    ];

    $form['metrics_settings']['titles'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Enable titles structure analysis'),
      '#description' => $this->t('Check headings hierarchy and structure.'),
      '#default_value' => $config->get('titles'),
    ];

    $form['metrics_settings']['recommended_title_metrics'] = [
      '#type' => 'number',
      '#title' => $this->t('Recommended number of title step'),
      '#description' => $this->t('Set the maximal title step of a content.'),
      '#min' => 0,
      '#max' => 6,
      '#step' => 1,
      '#default_value' => $config->get('recommended_title_metrics') ?? 4,
    ];

    $form['metrics_settings']['performance'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Enable performance analysis'),
      '#description' => $this->t('Check DOM elements count and estimated load time.'),
      '#default_value' => $config->get('performance'),
    ];


    $form['metrics_settings']['classes'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Add classes to check'),
      '#description' => $this->t('You can add several classes separated by ;. Don\'t put a . in front of the class.'),
      '#default_value' => $config->get('classes'),
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $this->config('text_clarity_checker.config')
         ->set('text_metrics', $form_state->getValue('text_metrics'))
         ->set('images', $form_state->getValue('images'))
         ->set('recommended_image_metrics', $form_state->getValue('recommended_image_metrics'))
         ->set('links', $form_state->getValue('links'))
         ->set('recommended_link_metrics', $form_state->getValue('recommended_link_metrics'))
         ->set('recommended_external_link_metrics', $form_state->getValue('recommended_external_link_metrics'))
         ->set('titles', $form_state->getValue('titles'))
         ->set('recommended_title_metrics', $form_state->getValue('recommended_title_metrics'))
         ->set('performance', $form_state->getValue('performance'))
         ->set('classes', $form_state->getValue('classes'))
         ->save();

    parent::submitForm($form, $form_state);
  }

}
