<?php

namespace Drupal\text_clarity_checker\Plugin\Block;

use Drupal\Core\Access\AccessResult;
use Drupal\Core\Block\BlockBase;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\Core\Session\AccountInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\Core\Config\ImmutableConfig;
use Drupal\Core\Plugin\Context\ContextDefinition;

/**
 * Provides a text clarity checker.
 *
 * @Block(
 *   id = "text_clarity_checker_block",
 *   admin_label = @Translation("Text clarity checker block"),
 *   category = @Translation("Blocks"),
 *   context_definitions = {
 *     "node" = @ContextDefinition(
 *       "entity:node",
 *       label = @Translation("Current Node")
 *     )
 *   }
 * )
 */
class TextClarityCheckerBlock extends BlockBase implements ContainerFactoryPluginInterface {

  /**
   * Constructor.
   */
  public function __construct(
              array           $configuration,
                              $plugin_id,
                              $plugin_definition,
    protected ImmutableConfig $config,
  ) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition): static {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('text_clarity_checker.settings')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function build(): array {
    $settings['textClarityChecker'] = [
      'text_metrics' => $this->config->get('text_metrics'),
      'images' => $this->config->get('images'),
      'recommended_image_metrics' => $this->config->get('recommended_image_metrics'),
      'links' => $this->config->get('links'),
      'recommended_link_metrics' => $this->config->get('recommended_link_metrics'),
      'recommended_external_link_metrics' => $this->config->get('recommended_external_link_metrics'),
      'titles' => $this->config->get('titles'),
      'recommended_title_metrics' => $this->config->get('recommended_title_metrics'),
      'performance' => $this->config->get('performance'),
      'classes' => $this->config->get('classes'),
    ];

    return [
      '#theme' => 'text_clarity_checker',
      '#config' => $settings['textClarityChecker'],
      '#attached' => [
        'library' => ['text_clarity_checker/text_clarity_checker'],
        'drupalSettings' => [
          'textClarityChecker' => $settings['textClarityChecker'],
        ],
      ],
      '#cache' => [
        'contexts' => ['route'],
        'tags' => ['config:text_clarity_checker.config'],
      ],
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getCacheMaxAge() {
    return 0;
  }

}
